summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--jstests/libs/override_methods/implicitly_shard_accessed_collections.js8
1 files changed, 5 insertions, 3 deletions
diff --git a/jstests/libs/override_methods/implicitly_shard_accessed_collections.js b/jstests/libs/override_methods/implicitly_shard_accessed_collections.js
index a29f68b7323..1fcb31da250 100644
--- a/jstests/libs/override_methods/implicitly_shard_accessed_collections.js
+++ b/jstests/libs/override_methods/implicitly_shard_accessed_collections.js
@@ -65,9 +65,11 @@
DBCollection.prototype.drop = function() {
var dropResult = originalDBCollectionDrop.apply(this, arguments);
- // Attempt to enable sharding on database and collection if not already done.
- shardCollection(this);
-
+ // TODO: Disable sharding collection on OSX until SERVER-28418 is fixed.
+ if (this.getDB().serverBuildInfo().buildEnvironment.target_os !== "macOS") {
+ // Attempt to enable sharding on database and collection if not already done.
+ shardCollection(this);
+ }
return dropResult;
};
}());